==> estateplat-common-1.1.0-20170221.062000-267-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSfxx.java <==
package cn.gtmap.estateplat.model.server.core;

import cn.gtmap.estateplat.core.support.mybatis.mapper.DoubleConvert;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 不动产收费单信息
 *
 * @author <a href="mailto: lijian@gtmap.cn">lj</a>
 * @version 1.0 15-12-5
 */
@Table(name = "BDC_SFXX")
public class BdcSfxx implements Serializable, BdcProid {
    @Id
    private String sfxxid;//收费 信息id

    private String wiid;//工作流ID

    private String proid;//项目id

    private Date sjrq;//收缴日期

    private Double hj;//合计

    private String bz;//备注

    private String sfdcsr;//收费单初审人

    private String sfdfsr;//收费单复审人

    private Double hsje;//核收金额

    private String sfdw;//收费机构

    private String sfzt;//收费状态 1:转结 0:已收费

    private String jkr;//交款人

    private String jkrzh;//缴款人账号

    private String jkrkhyh;//缴款人开户银行

    private String skr;//收款人

    private String skrzh;//收款人账号

    private String skrkhyh;//收款人开户银行

    private String sfdwdm;//收费单位代码


    public String getSfxxid() {
        return sfxxid;
    }

    public void setSfxxid(String sfxxid) {
        this.sfxxid = sfxxid;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public Double getHsje() {
        return hsje;
    }

    public void setHsje(Double hsje) {
        this.hsje = hsje;
    }

    public String getSfdw() {
        return sfdw;
    }

    public void setSfdw(String sfdw) {
        this.sfdw = sfdw;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Date getSjrq() {
        return sjrq;
    }

    public void setSjrq(Date sjrq) {
        this.sjrq = sjrq;
    }

    public Double getHj() {
        return hj;
    }

    public void setHj(Double hj) {
        this.hj = hj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSfdcsr() {
        return sfdcsr;
    }

    public void setSfdcsr(String sfdcsr) {
        this.sfdcsr = sfdcsr;
    }

    public String getSfdfsr() {
        return sfdfsr;
    }

    public void setSfdfsr(String sfdfsr) {
        this.sfdfsr = sfdfsr;
    }

    public String getSfzt() {
        return sfzt;
    }

    public void setSfzt(String sfzt) {
        this.sfzt = sfzt;
    }

    public String getJkr() {
        return jkr;
    }

    public void setJkr(String jkr) {
        this.jkr = jkr;
    }

    public String getJkrzh() {
        return jkrzh;
    }

    public void setJkrzh(String jkrzh) {
        this.jkrzh = jkrzh;
    }

    public String getJkrkhyh() {
        return jkrkhyh;
    }

    public void setJkrkhyh(String jkrkhyh) {
        this.jkrkhyh = jkrkhyh;
    }

    public String getSkr() {
        return skr;
    }

    public void setSkr(String skr) {
        this.skr = skr;
    }

    public String getSkrzh() {
        return skrzh;
    }

    public void setSkrzh(String skrzh) {
        this.skrzh = skrzh;
    }

    public String getSkrkhyh() {
        return skrkhyh;
    }

    public void setSkrkhyh(String skrkhyh) {
        this.skrkhyh = skrkhyh;
    }

    public String getSfdwdm() {
        return sfdwdm;
    }

    public void setSfdwdm(String sfdwdm) {
        this.sfdwdm = sfdwdm;
    }
}

==> estateplat-common-1.2.1-20170713.060811-58-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSfxx.java <==
package cn.gtmap.estateplat.model.server.core;

import cn.gtmap.estateplat.core.support.mybatis.mapper.DoubleConvert;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 不动产收费单信息
 *
 * @author <a href="mailto: lijian@gtmap.cn">lj</a>
 * @version 1.0 15-12-5
 */
@Table(name = "BDC_SFXX")
public class BdcSfxx implements Serializable, BdcProid {
    @Id
    private String sfxxid;//收费 信息id

    private String wiid;//工作流ID

    private String proid;//项目id

    private Date sjrq;//收缴日期

    private Double hj;//合计

    private String bz;//备注

    private String sfdcsr;//收费单初审人

    private String sfdfsr;//收费单复审人

    private Double hsje;//核收金额

    private String sfdw;//收费机构

    private String sfzt;//收费状态 1:转结 0:已收费

    private String jkr;//交款人

    private String jkrzh;//缴款人账号

    private String jkrkhyh;//缴款人开户银行

    private String skr;//收款人

    private String skrzh;//收款人账号

    private String skrkhyh;//收款人开户银行

    private String sfdwdm;//收费单位代码

    private String sfztczr;//收费状态操作人

    private Date sfztczrq;//收费状态操作日期

    public String getSfxxid() {
        return sfxxid;
    }

    public void setSfxxid(String sfxxid) {
        this.sfxxid = sfxxid;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public Double getHsje() {
        return hsje;
    }

    public void setHsje(Double hsje) {
        this.hsje = hsje;
    }

    public String getSfdw() {
        return sfdw;
    }

    public void setSfdw(String sfdw) {
        this.sfdw = sfdw;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Date getSjrq() {
        return sjrq;
    }

    public void setSjrq(Date sjrq) {
        this.sjrq = sjrq;
    }

    public Double getHj() {
        return hj;
    }

    public void setHj(Double hj) {
        this.hj = hj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSfdcsr() {
        return sfdcsr;
    }

    public void setSfdcsr(String sfdcsr) {
        this.sfdcsr = sfdcsr;
    }

    public String getSfdfsr() {
        return sfdfsr;
    }

    public void setSfdfsr(String sfdfsr) {
        this.sfdfsr = sfdfsr;
    }

    public String getSfzt() {
        return sfzt;
    }

    public void setSfzt(String sfzt) {
        this.sfzt = sfzt;
    }

    public String getJkr() {
        return jkr;
    }

    public void setJkr(String jkr) {
        this.jkr = jkr;
    }

    public String getJkrzh() {
        return jkrzh;
    }

    public void setJkrzh(String jkrzh) {
        this.jkrzh = jkrzh;
    }

    public String getJkrkhyh() {
        return jkrkhyh;
    }

    public void setJkrkhyh(String jkrkhyh) {
        this.jkrkhyh = jkrkhyh;
    }

    public String getSkr() {
        return skr;
    }

    public void setSkr(String skr) {
        this.skr = skr;
    }

    public String getSkrzh() {
        return skrzh;
    }

    public void setSkrzh(String skrzh) {
        this.skrzh = skrzh;
    }

    public String getSkrkhyh() {
        return skrkhyh;
    }

    public void setSkrkhyh(String skrkhyh) {
        this.skrkhyh = skrkhyh;
    }

    public String getSfdwdm() {
        return sfdwdm;
    }

    public void setSfdwdm(String sfdwdm) {
        this.sfdwdm = sfdwdm;
    }

    public String getSfztczr() {
        return sfztczr;
    }

    public void setSfztczr(String sfztczr) {
        this.sfztczr = sfztczr;
    }

    public Date getSfztczrq() {
        return sfztczrq;
    }

    public void setSfztczrq(Date sfztczrq) {
        this.sfztczrq = sfztczrq;
    }
}
